"""Contains all constants."""

ENV_VAR_LOG_LEVEL = "VPU_LOG_LEVEL"
ENV_VAR_DOCKER_TAGS = "VPU_DOCKER_TAGS"
ENV_VAR_IMAGE_NAME = "VPU_DOCKER_IMAGE_NAME"
ENV_VAR_REPOSITORIES = "VPU_DOCKER_REPOSITORIES"
ENV_VAR_DOCKER_REGISTRY = "VPU_DOCKER_REGISTRY"
